@@ -1,4 +1,5 @@
 import platform
+import hashlib
 import requests
 import stat
 from contextlib import contextmanager
@@ -194,6 +195,8 @@ def _wait_postgres(config):
         client = docker.from_env()
         postgres_containers = []
         for container_id in container_ids:
+            if not container_id:
+                continue
             container = client.containers.get(container_id)
             if not container:
                 continue
@@ -203,6 +206,11 @@ def _wait_postgres(config):
 
         # if running containers wait for health state:
         if not postgres_containers:
+            abort((
+                "No running postgres container found. "
+                "Perhaps you have to start it with "
+                "'odoo up -d postgres' first?"
+            ))
             raise Exception("No running container found!")
 
         _wait_for_port(conn.host, conn.port, timeout=30)
@@ -844,9 +852,6 @@ def split_hub_url(config):
     password = password.split("@")[0]
     url = url.split("@")[1]
     url, prefix = url.split("/", 1)
-    click.secho((
-        f"Using docker hub {url}"
-    ), fg='green')
     return {
         'url': url,
         'password': password,
@@ -905,3 +910,19 @@ def download_file(url):
             shutil.copyfileobj(r.raw, f)
 
     return Path(local_filename)
+
+def get_hash(text):
+    if isinstance(text, str):
+        text = text.encode('utf8')
+    return hashlib.sha1(text).hexdigest()
+
+def get_directory_hash(path):
+    hex = b""
+    for file in sorted(path.glob("**/*")):
+        if file.name.startswith("."):
+            continue
+        if file.is_dir():
+            continue
+        hex = get_hash(hex + file.read_bytes()).encode('utf8')
+    return str(hex)
+
